jQuery(document).ready(function($) {
    // Добавляем модальное окно в DOM, если его еще нет
    if ($('#telegapay-modal').length === 0) {
        $('body').append(`
            <div id="telegapay-modal" style="display: none;">
                <div class="telegapay-modal-overlay"></div>
                <div class="telegapay-modal-container">
                    <div class="telegapay-modal-header">
                        <span class="telegapay-modal-title">Оплата</span>
                        <span class="telegapay-modal-close">&times;</span>
                    </div>
                    <div class="telegapay-modal-body">
                        <iframe id="telegapay-payment-frame" frameborder="0" allowtransparency="true"></iframe>
                    </div>
                </div>
            </div>
        `);
    }

    // Закрытие модального окна при клике на крестик
    $(document).on('click', '.telegapay-modal-close', function() {
        closePaymentModal();
    });

    // Закрытие модального окна при клике на оверлей
    $(document).on('click', '.telegapay-modal-overlay', function() {
        closePaymentModal();
    });

    // Функция для закрытия модального окна
    function closePaymentModal() {
        $('#telegapay-modal').fadeOut(300);
        $('#telegapay-payment-frame').attr('src', '');
        $('body').css('overflow', 'auto'); // Возвращаем прокрутку страницы
    }

    // Функция для открытия модального окна
    function openPaymentModal(paymentUrl) {
        $('#telegapay-payment-frame').attr('src', paymentUrl);
        $('#telegapay-modal').fadeIn(300);
        $('body').css('overflow', 'hidden'); // Блокируем прокрутку страницы
    }

    // Обработчик сообщений от iframe
    window.addEventListener('message', function(event) {
        // Проверяем, что сообщение от нашего домена telegapay.pro
        if (event.origin.includes('telegapay.pro')) {
            try {
                const data = typeof event.data === 'string' ? JSON.parse(event.data) : event.data;

                // Обрабатываем различные события от формы оплаты
                if (data.action === 'payment_success') {
                    closePaymentModal();
                    // Можно добавить перенаправление на страницу успешной оплаты
                    // window.location.href = '/thank-you-page';
                } else if (data.action === 'payment_cancel') {
                    closePaymentModal();
                } else if (data.action === 'payment_error') {
                    closePaymentModal();
                    alert('Произошла ошибка при обработке платежа: ' + data.message);
                }
            } catch (e) {
                console.error('Error processing message from payment form:', e);
            }
        }
    });

    // Обработчик клика по кнопке оплаты
    $(document).on('click', '[id^=telegapay-button-]', function(e) {
        e.preventDefault();

        var button = $(this);
        var buttonId = button.attr('id');
        var loader = $('#' + buttonId + '-loader');

        // Показываем индикатор загрузки
        button.prop('disabled', true);
        loader.show();

        // Получаем данные платежа
        var amount = button.data('amount');
        var currency = button.data('currency');
        var description = button.data('description');
        var paymentMethod = button.data('payment-method');
        var userId = button.data('user-id');

        // Отправляем AJAX запрос
        $.ajax({
            url: telegapay_params.ajax_url,
            type: 'POST',
            data: {
                action: 'telegapay_create_payment',
                nonce: telegapay_params.nonce,
                amount: amount,
                currency: currency,
                description: description,
                payment_method: paymentMethod,
                user_id: userId
            },
            success: function(response) {
                // Скрываем индикатор загрузки
                button.prop('disabled', false);
                loader.hide();

                if (response.success && response.data.payment_url) {
                    // Открываем модальное окно с формой оплаты
                    openPaymentModal(response.data.payment_url);
                } else {
                    // Показываем ошибку
                    alert(response.data.message || 'Произошла ошибка при создании платежа');
                }
            },
            error: function() {
                // Скрываем индикатор загрузки
                button.prop('disabled', false);
                loader.hide();

                // Показываем ошибку
                alert('Произошла ошибка при отправке запроса');
            }
        });
    });
});